summaryrefslogtreecommitdiffstats
path: root/kexi/formeditor/widgetpropertyset.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/formeditor/widgetpropertyset.h')
-rw-r--r--kexi/formeditor/widgetpropertyset.h83
1 files changed, 42 insertions, 41 deletions
diff --git a/kexi/formeditor/widgetpropertyset.h b/kexi/formeditor/widgetpropertyset.h
index 71e7b2254..d330e4edf 100644
--- a/kexi/formeditor/widgetpropertyset.h
+++ b/kexi/formeditor/widgetpropertyset.h
@@ -21,14 +21,14 @@
#ifndef KFD_WIDGETPROPERTYSET_H
#define KFD_WIDGETPROPERTYSET_H
-#include <qobject.h>
-#include <qstrlist.h>
+#include <tqobject.h>
+#include <tqstrlist.h>
#include <koproperty/set.h>
#include <koproperty/property.h>
-class QMetaObject;
-class QWidget;
+class TQMetaObject;
+class TQWidget;
namespace KFormDesigner {
@@ -38,27 +38,28 @@ class WidgetPropertySetPrivate;
class WidgetInfo;
class CommandGroup;
-class KFORMEDITOR_EXPORT WidgetPropertySet : public QObject
+class KFORMEDITOR_EXPORT WidgetPropertySet : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
- WidgetPropertySet(QObject *parent);
+ WidgetPropertySet(TQObject *tqparent);
~WidgetPropertySet();
// FormManager* manager();
- KoProperty::Property& operator[](const QCString &name);
+ KoProperty::Property& operator[](const TQCString &name);
- KoProperty::Property& property(const QCString &name);
+ KoProperty::Property& property(const TQCString &name);
- bool contains(const QCString &property);
+ bool tqcontains(const TQCString &property);
/*! i18n function used by factories to add new property caption.
Should be called on Factory creation. */
- void addPropertyCaption(const QCString &property, const QString &caption);
+ void addPropertyCaption(const TQCString &property, const TQString &caption);
- void addValueCaption(const QCString &value, const QString &caption);
+ void addValueCaption(const TQCString &value, const TQString &caption);
public slots:
/*! Sets the widget which properties are shown in the property editor.
@@ -69,10 +70,10 @@ class KFORMEDITOR_EXPORT WidgetPropertySet : public QObject
even if these were already displayed.
If \a showPropertySet is true (the default), property editor will be updated for the current selection.
This flag is set to false when we're selecting multiple widgets. */
- void setSelectedWidget(QWidget *w, bool add = false, bool forceReload = false,
+ void setSelectedWidget(TQWidget *w, bool add = false, bool forceReload = false,
bool moreWillBeSelected = false);
- void setSelectedWidgetWithoutReload(QWidget *w, bool add = false, bool moreWillBeSelected = false) {
+ void setSelectedWidgetWithoutReload(TQWidget *w, bool add = false, bool moreWillBeSelected = false) {
setSelectedWidget(w, add, false, moreWillBeSelected);
}
@@ -86,37 +87,37 @@ class KFORMEDITOR_EXPORT WidgetPropertySet : public QObject
/*! This slot is called when the watched widget is destroyed. Resets the buffer.*/
void slotWidgetDestroyed();
-// void setPropertyValueInDesignMode(QWidget* widget, const QMap<QCString, QVariant> &propValues,
- void createPropertyCommandsInDesignMode(QWidget* widget, const QMap<QCString,
- QVariant> &propValues, CommandGroup *group, bool addToActiveForm = true,
+// void setPropertyValueInDesignMode(TQWidget* widget, const TQMap<TQCString, TQVariant> &propValues,
+ void createPropertyCommandsInDesignMode(TQWidget* widget, const TQMap<TQCString,
+ TQVariant> &propValues, CommandGroup *group, bool addToActiveForm = true,
bool execFlagForSubCommands = false);
signals:
/*! This signal is emitted when a property was changed.
\a widg is the widget concerned, \a property
is the name of the modified property, and \a v is the new value of this property. */
- void widgetPropertyChanged(QWidget *w, const QCString &property, const QVariant &v);
+ void widgetPropertyChanged(TQWidget *w, const TQCString &property, const TQVariant &v);
/*! This signal is emitted when the name of the widget is modified.
\a oldname is the name of the widget before the
change, \a newname is the name after renaming. */
- void widgetNameChanged(const QCString &oldname, const QCString &newname);
+ void widgetNameChanged(const TQCString &oldname, const TQCString &newname);
protected:
/*! Adds the widget in d->widgets, and updates property visibilty. */
- void addWidget(QWidget *w);
+ void addWidget(TQWidget *w);
/*! Fills the list with properties related to the widget \a w. Also updates
properties old value and changed state. */
- void createPropertiesForWidget(QWidget *w);
+ void createPropertiesForWidget(TQWidget *w);
/*! Creates a map property description->prop. value from
the list of keys \a list. */
- KoProperty::Property::ListData* createValueList(WidgetInfo *winfo, const QStringList &list);
+ KoProperty::Property::ListData* createValueList(WidgetInfo *winfo, const TQStringList &list);
/*! Changes \a property old value and changed state, using the value
stored in \a tree. Optional \a meta can be specified if you need to handle enum values. */
- void updatePropertyValue(ObjectTreeItem *tree, const char *property, const QMetaProperty *meta = 0);
+ void updatePropertyValue(ObjectTreeItem *tree, const char *property, const TQMetaProperty *meta = 0);
/*! \return the property list hold by this object. Do not modify the list,
just use this method to change Editor's list. */
@@ -131,7 +132,7 @@ class KFORMEDITOR_EXPORT WidgetPropertySet : public QObject
/*! Checks if the name entered by user is valid, ie that it is
a valid identifier, and that there is no name conflict. */
- bool isNameValid(const QString &name);
+ bool isNameValid(const TQString &name);
/*! Saves 'enabled' property, and takes care of updating widget's palette. */
void saveEnabledProperty(bool value);
@@ -139,7 +140,7 @@ class KFORMEDITOR_EXPORT WidgetPropertySet : public QObject
/*! This function filters the event of the selected widget to
automatically updates the "geometry" property
when the widget is moved or resized in the Form. */
- bool eventFilter(QObject *o, QEvent *ev);
+ bool eventFilter(TQObject *o, TQEvent *ev);
/*! Changes undoing state of the list. Used by Undo command to
prevent recursion. */
@@ -150,29 +151,29 @@ class KFORMEDITOR_EXPORT WidgetPropertySet : public QObject
/*! This function is used to filter the properties to be shown
(ie not show "caption" if the widget isn't toplevel).
\return true if the property should be shown. False otherwise.*/
- bool isPropertyVisible(const QCString &property, bool isTopLevel,
- const QCString &classname=QCString());
+ bool isPropertyVisible(const TQCString &property, bool isTopLevel,
+ const TQCString &classname=TQCString());
// Following functions are used to create special types of properties, different
- // from Q_PROPERTY
+ // from TQ_PROPERTY
- /*! Creates the properties related to alignment (ie hAlign, vAlign and WordBreak) for
- the QWidget \a widget. \a subwidget is the same as \a widget if the widget itself handles
+ /*! Creates the properties related to tqalignment (ie hAlign, vAlign and WordBreak) for
+ the TQWidget \a widget. \a subwidget is the same as \a widget if the widget itself handles
the property and it's a child widget if the child handles the property.
For example, the second case is true for KexiDBAutoField.
- \a meta is the QMetaProperty for "alignment" property" of subwidget. */
- void createAlignProperty(const QMetaProperty *meta, QWidget *widget, QWidget *subwidget);
+ \a meta is the TQMetaProperty for "tqalignment" property" of subwidget. */
+ void createAlignProperty(const TQMetaProperty *meta, TQWidget *widget, TQWidget *subwidget);
- /*! Saves the properties related to alignment (ie hAlign, vAlign and WordBreak)
- and modifies the "alignment" property of the widget.*/
- void saveAlignProperty(const QString &property);
+ /*! Saves the properties related to tqalignment (ie hAlign, vAlign and WordBreak)
+ and modifies the "tqalignment" property of the widget.*/
+ void saveAlignProperty(const TQString &property);
- /*! Creates the "layout" property, for the Container representing \a item. */
+ /*! Creates the "tqlayout" property, for the Container representing \a item. */
void createLayoutProperty(ObjectTreeItem *item);
- /*! Saves the "layout" property and changes the Container 's layout (
+ /*! Saves the "tqlayout" property and changes the Container 's tqlayout (
using Container::setLayout() ).*/
- void saveLayoutProperty(const QString &property, const QVariant &value);
+ void saveLayoutProperty(const TQString &property, const TQVariant &value);
// Some i18n functions
//! Adds translations for general properties, by adding items in d->propDesc
@@ -180,17 +181,17 @@ class KFORMEDITOR_EXPORT WidgetPropertySet : public QObject
/*! \return The i18n'ed name of the property whose name is \a name, that will be
displayed in PropertyEditor. */
- QString propertyCaption(const QCString &name);
+ TQString propertyCaption(const TQCString &name);
/*! \return The i18n'ed name of the property's value whose name is \a name. */
- QString valueCaption(const QCString &name);
+ TQString valueCaption(const TQCString &name);
/*! \return The i18n'ed list of values, that will be shown by Property
Editor (using descFromValue()).*/
- //QStringList captionForList(const QStringList &list);
+ //TQStringList captionForList(const TQStringList &list);
//! Helper
- void emitWidgetPropertyChanged(QWidget *w, const QCString& property, const QVariant& value);
+ void emitWidgetPropertyChanged(TQWidget *w, const TQCString& property, const TQVariant& value);
private:
WidgetPropertySetPrivate *d;